==> v1.2.5042.tar.gz: rstudio-1.2.5042/src/gwt/src/org/rstudio/studio/client/common/dependencies/model/Dependency.java <==
/*
 * CompilePdfResult.java
 *
 * Copyright (C) 2009-12 by RStudio, Inc.
 *
 * Unless you have received this program directly from RStudio pursuant
 * to the terms of a commercial license agreement with RStudio, then
 * this program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */

package org.rstudio.studio.client.common.dependencies.model;


import com.google.gwt.core.client.JavaScriptObject;

public class Dependency extends JavaScriptObject
{
   public static final int CRAN_PACKAGE = 0;
   public static final int EMBEDDED_PACKAGE = 1;
   
   protected Dependency()
   {
   }
   
   public static Dependency cranPackage(String name)
   {
      // use version '0.0.0' just to indicate that any currently installed
      // version of the requested package should suffice
      return cranPackage(name, "0.0.0", false);
   }
   
   public static Dependency cranPackage(String name, 
                                        String version)
   {
      return cranPackage(name, version, false);
   }
            
            
   
   public native static final Dependency cranPackage(String name, 
                                                     String version,
                                                     boolean source) /*-{
      var dep = new Object();
      dep.type = 0;
      dep.name = name;
      dep.version = version;
      dep.source = source;
      return dep;
   }-*/;
   
   public native static final Dependency embeddedPackage(String name) /*-{
      var dep = new Object();
      dep.type = 1;
      dep.name = name;
      dep.version = "";
      dep.source = true;
      return dep;
   }-*/;
   
   public final native int getType() /*-{
      return this.type;
   }-*/;
   
   public final native String getName() /*-{
      return this.name;
   }-*/;
   
   public final native String getVersion() /*-{
      return this.version;
   }-*/;
   
   public final native boolean getSource() /*-{
      return this.source;
   }-*/;

   public final native String getAvailableVersion() /*-{
      return this.available_version;
   }-*/;

   public final native boolean getVersionSatisfied() /*-{
      return this.version_satisfied;
   }-*/;
   
   public final boolean isEqualTo(Dependency other)
   {
      return (getType()    == other.getType() &&
              getName()    == other.getName() &&
              getVersion() == other.getVersion() &&
              getSource()  == other.getSource());
   }
}

==> v1.4.1717.tar.gz: rstudio-1.4.1717/src/gwt/src/org/rstudio/studio/client/common/dependencies/model/Dependency.java <==
/*
 * Dependency.java
 *
 * Copyright (C) 2021 by RStudio, PBC
 *
 * Unless you have received this program directly from RStudio pursuant
 * to the terms of a commercial license agreement with RStudio, then
 * this program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */

package org.rstudio.studio.client.common.dependencies.model;


import com.google.gwt.core.client.JavaScriptObject;

public class Dependency extends JavaScriptObject
{
   protected Dependency()
   {
   }

   public static Dependency cranPackage(String name)
   {
      // use version '0.0.0' just to indicate that any currently installed
      // version of the requested package should suffice
      return cranPackage(name, "0.0.0");
   }

   public final native static Dependency cranPackage(String name, String version) /*-{
      return {
         "name": name,
         "version": version,
         "location": "cran",
         "source": false
      };
   }-*/;
   
   public final native String getLocation() /*-{
      return this.location;
   }-*/;
   
   public final native String setName(String name) /*-{
      this.name = name;
   }-*/;
   
   public final native String getName() /*-{
      return this.name;
   }-*/;
   
   public final native String getVersion() /*-{
      return this.version;
   }-*/;
   
   public final native boolean getSource() /*-{
      return this.source;
   }-*/;

   public final native String getAvailableVersion() /*-{
      return this.available_version;
   }-*/;

   public final native boolean getVersionSatisfied() /*-{
      return this.version_satisfied;
   }-*/;
   
   public final boolean isEqualTo(Dependency other)
   {
      return (getLocation()  == other.getLocation() &&
              getName()      == other.getName() &&
              getVersion()   == other.getVersion() &&
              getSource()    == other.getSource());
   }
}
